@@ -163,6 +163,7 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
     
         if(records.Index==records.MaxArrayDataLen-1): 
             print "Stopped, array is full"
+            data.Status="Stopped, array is full!"
             QtGui.QMessageBox.warning(RecordWindow, 'Memory is full!', "You reached the end of the recording capacity (24h)!\nThe recording stops now.", QtGui.QMessageBox.Ok)
 #            RecordWindow.StopMeasurement()
             StopMeasurement() #but keep alarm active!
@@ -173,6 +174,7 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
 #        print "Alarm is active"
         if(data.StopAfterAlarm==True):
 #            print "Stop measurement, alarm is active"
+            data.Status="Alarm got activated, stopped recording"
             StopMeasurement() #but keep alarm active!
   
 
@@ -187,6 +189,7 @@ def InitMeasurement():
     global app,  RecordWindowGraph
 
     data.sample_index=0
+    data.Status="Recording..."
 
     records.User=data.user
     records.SWversion=data.version
@@ -206,6 +209,8 @@ def InitMeasurement():
         data.interval=10 #Fast mode for testing
         data.Xscale=0 #set to max zoom level
     
+#    data.interval=1 #Debugging
+    
     #change to offline mode and silent profile if requested
     if(data.QuickMode==False):
         if(data.OfflineMode==True): #change to offline mode
@@ -560,6 +565,7 @@ class frmRecordWindow(QMainWindow):
         else: #Do only recording, no alarm
             self.ui.lblAlarmTime.setText("(No Alarm set)")
                         
+        self.ui.lblNote.setText("")
         self.UpdateScreen()
         
         
@@ -573,6 +579,8 @@ class frmRecordWindow(QMainWindow):
             d=time.strftime("%H:%M:%S", time.gmtime(time_difference))
             self.ui.lblElapsedTime.setText(d + " ("+str(records.Index)+" entries)")
         else: self.UpdateScreenStop()
+        
+        self.ui.lblStatus.setText(data.Status)
             
         if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
         else: self.ui.bZoomIn.setEnabled(True)
@@ -591,11 +599,13 @@ class frmRecordWindow(QMainWindow):
 
     def UpdateScreenStop(self):
         self.ui.bStop.setText("Close")
-        t=time.mktime(time.localtime())
-        time_difference=t-data.StartTimeSec
-#        d=time.strftime("%X", time.gmtime(time_difference))
-        d=time.strftime("%H:%M:%S", time.gmtime(time_difference))
-        self.ui.lblElapsedTime.setText(d + " ("+str(records.Index)+" entries, stopped)")
+#        t=time.mktime(time.localtime())
+#        time_difference=t-data.StartTimeSec
+##        d=time.strftime("%X", time.gmtime(time_difference))
+#        d=time.strftime("%H:%M:%S", time.gmtime(time_difference))
+##        self.ui.lblElapsedTime.setText(d + " ("+str(records.Index)+" entries, stopped)")
+#        self.ui.lblElapsedTime.setText(d + " ("+str(records.Index)+" entries)")
+        self.ui.lblStatus.setText(data.Status)
         
         
         
@@ -1035,7 +1045,8 @@ class frmConfigWindow(QMainWindow):
         self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
               
         QtCore.QObject.connect(self.ui.bEditUserName, QtCore.SIGNAL("clicked()"), self.EditUserName)
-        QtCore.QObject.connect(self.ui.SlrDelayStart,SIGNAL("valueChanged(int)"),self.SliderMoved)
+        QtCore.QObject.connect(self.ui.SlrDelayStart,SIGNAL("valueChanged(int)"),self.DelaySliderMoved)
+        QtCore.QObject.connect(self.ui.SlrYscale,SIGNAL("valueChanged(int)"),self.YscaleSliderMoved)
         
         
 
@@ -1049,9 +1060,11 @@ class frmConfigWindow(QMainWindow):
         else: self.ui.cSilentProfile.setChecked(False)      
         if(data.StopAfterAlarm==True): self.ui.cStopAfterAlarm.setChecked(True)
         else: self.ui.cStopAfterAlarm.setChecked(False)        
-        self.ui.lblUserName.setText(data.user)
-        self.ui.lblDelayStart.setText(str(data.DelayStartTime)+" sec")
+        self.ui.lblUser.setText("User name: "+data.user)
+        self.ui.lblDelayStart.setText("Start delay: "+str(data.DelayStartTime)+" sec")
         self.ui.SlrDelayStart.setValue(int(data.DelayStartTime))
+        self.ui.lblYscale.setText("Y scaling: "+str(data.Yscale))
+        self.ui.SlrYscale.setValue(int(data.Yscale))
 
 
     ###########################################################################
@@ -1088,18 +1101,25 @@ class frmConfigWindow(QMainWindow):
     ###########################################################################
     def EditUserName(self):
         EditUserName()
-        self.ui.lblUserName.setText(data.user)
+        self.ui.lblUser.setText(data.user)
         
 
     ###########################################################################
     ## 
     ###########################################################################
-    def SliderMoved(self):
+    def DelaySliderMoved(self):
         x=self.ui.SlrDelayStart.value()
         data.DelayStartTime=x
         self.ui.lblDelayStart.setText(str(data.DelayStartTime)+" sec")
 
 
+    ###########################################################################
+    ## 
+    ###########################################################################
+    def YscaleSliderMoved(self):
+        x=self.ui.SlrYscale.value()
+        data.Yscale=int(x)
+        self.ui.lblYscale.setText("Y scaling: "+str(data.Yscale))
 
 
 
@@ -1207,7 +1227,7 @@ class frmAdditionalInfoWindow(QMainWindow):
             if(records.AlarmTime_seconds!=-1): #alarm went off
                 alarm=alarm+"<b>Alarm:</b> Alarm went off on: "+strftime("%a. %d.%m.%Y  %H:%M:%S", records.AlarmTime_tuple)+"<br>"
                 if(records.AlarmTimeWindowEnd_seconds<=records.AlarmTime_seconds):
-                    alarm=alarm+"<b>Alarm reason:</b> End of alarm time window\n"
+                    alarm=alarm+"<b>Alarm reason:</b> End of alarm time window<br>"
                 else:
                     alarm=alarm+"<b>Alarm reason:</b> Movements over trigger level<br>"
             else:
